@@ -73,7 +73,7 @@ def info(kafka_connect):
 
 @cli.command()
 @click.option('-ex', '--expand', type=click.Choice(['status', 'info']), envvar='KAFKA_CONNECT_LIST_EXPAND', show_envvar=True, help='Optional parameter that retrieves additional information about the connectors.')
-@click.option('-p', '--connector-pattern', default=None, envvar='KAFKA_CONNECT_LIST_CONNECTOR_PATTERN', show_envvar=True, help='The regex pattern that will list only the connectors that match when the --expand option is set.')
+@click.option('-p', '--connector-pattern', default=None, metavar="REGEX", envvar='KAFKA_CONNECT_LIST_CONNECTOR_PATTERN', show_envvar=True, help='The regex pattern that will list only the connectors that match when the --expand option is set.')
 @click.pass_obj
 def list(kafka_connect, expand, connector_pattern):
     """Get a list of active connectors."""
@@ -141,7 +141,7 @@ def status(kafka_connect, connector):
 @click.option('-i', '--include-tasks', is_flag=True, default=False, envvar='KAFKA_CONNECT_INCLUDE_TASKS', show_envvar=True, help='Whether to include the Task objects in the restart operation.')
 @click.option('-o', '--only-failed', is_flag=True, default=False, envvar='KAFKA_CONNECT_ONLY_FAILED', show_envvar=True, help='Whether to restart only failed Task objects.')
 @click.option('-a', '--all-connectors', is_flag=True, default=False, envvar='KAFKA_CONNECT_RESTART_ALL', show_envvar=True, help='Whether to restart all connectors.')
-@click.option('-p', '--connector-pattern', default=None, envvar='KAFKA_CONNECT_RESTART_ALL_CONNECTOR_PATTERN', show_envvar=True, help='The regex pattern that will restart only the connectors that match when the --all-connectors option is set.')
+@click.option('-p', '--connector-pattern', default=None, metavar="REGEX", envvar='KAFKA_CONNECT_RESTART_ALL_CONNECTOR_PATTERN', show_envvar=True, help='The regex pattern that will restart only the connectors that match when the --all-connectors option is set.')
 @click.pass_obj
 def restart(kafka_connect, connector, include_tasks, only_failed, all_connectors, connector_pattern):
     """Restart a connector or all connectors matching a certain pattern."""
@@ -154,7 +154,7 @@ def restart(kafka_connect, connector, include_tasks, only_failed, all_connectors
 @cli.command()
 @click.argument('connector', required=False)
 @click.option('-a', '--all-connectors', is_flag=True, default=False, envvar='KAFKA_CONNECT_PAUSE_ALL', show_envvar=True, help='Whether to pause all connectors.')
-@click.option('-p', '--connector-pattern', default=None, envvar='KAFKA_CONNECT_PAUSE_CONNECTOR_PATTERN', show_envvar=True, help='The regex pattern that will pause only the connectors that match when the --all-connectors option is set.')
+@click.option('-p', '--connector-pattern', default=None, metavar="REGEX", envvar='KAFKA_CONNECT_PAUSE_CONNECTOR_PATTERN', show_envvar=True, help='The regex pattern that will pause only the connectors that match when the --all-connectors option is set.')
 @click.pass_obj
 def pause(kafka_connect, connector, all_connectors, connector_pattern):
     """Pauses a connector or all connectors that match a certain pattern."""
@@ -168,7 +168,7 @@ def pause(kafka_connect, connector, all_connectors, connector_pattern):
 @cli.command()
 @click.argument('connector', required=False)
 @click.option('-a', '--all-connectors', is_flag=True, default=False, envvar='KAFKA_CONNECT_RESUME_ALL', show_envvar=True, help='Whether to resume all connectors.')
-@click.option('-p', '--connector-pattern', default=None, envvar='KAFKA_CONNECT_RESUME_CONNECTOR_PATTERN', show_envvar=True, help='The regex pattern that will resume only the connectors that match when the --all-connectors option is set.')
+@click.option('-p', '--connector-pattern', default=None, metavar="REGEX", envvar='KAFKA_CONNECT_RESUME_CONNECTOR_PATTERN', show_envvar=True, help='The regex pattern that will resume only the connectors that match when the --all-connectors option is set.')
 @click.pass_obj
 def resume(kafka_connect, connector, all_connectors, connector_pattern):
     """Resumes a connector or all connectors that match a certain pattern."""
@@ -182,7 +182,7 @@ def resume(kafka_connect, connector, all_connectors, connector_pattern):
 @cli.command()
 @click.argument('connector', required=False)
 @click.option('-a', '--all-connectors', is_flag=True, default=False, envvar='KAFKA_CONNECT_DELETE_ALL', show_envvar=True, help='Whether to delete all connectors.')
-@click.option('-p', '--connector-pattern', default=None, envvar='KAFKA_CONNECT_DELETE_CONNECTOR_PATTERN', show_envvar=True, help='The regex pattern that will delete only the connectors that match when the --all-connectors option is set.')
+@click.option('-p', '--connector-pattern', default=None, metavar="REGEX", envvar='KAFKA_CONNECT_DELETE_CONNECTOR_PATTERN', show_envvar=True, help='The regex pattern that will delete only the connectors that match when the --all-connectors option is set.')
 @click.pass_obj
 def delete(kafka_connect, connector, all_connectors, connector_pattern):
     """Deletes a connector or all connectors that match a certain pattern."""
